iotools.is_underscore_delimited_lowercase_package_name
======================================================

.. autofunction:: abjad.tools.iotools.is_underscore_delimited_lowercase_package_name.is_underscore_delimited_lowercase_package_name
